@@ -28,7 +28,7 @@ import graphviz
 import graphviz.backend
 from dtreeviz.shadow import *
 from sklearn import tree
-from simba.drop_bp_cords import drop_bp_cords, GenerateMetaDataFileHeaders
+from drop_bp_cords import drop_bp_cords, GenerateMetaDataFileHeaders
 from sklearn.metrics import make_scorer, accuracy_score, precision_score, recall_score, f1_score
 from sklearn.model_selection import cross_val_score, cross_validate
 # import timeit
@@ -306,6 +306,8 @@ def trainmodel2(inifile):
             generateFeatureImportanceBarGraph(log_df, N_feature_importance_bars)
         if generate_features_importance_bar_graph != 'yes':
             N_feature_importance_bars = 'NaN'
+            generate_features_importance_log = 'no'
+
 
         generate_example_decision_tree_fancy = config.get('create ensemble settings','generate_example_decision_tree_fancy')
         if generate_example_decision_tree_fancy == 'yes':
